% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dlmtool.R
\name{spict2DLMtool}
\alias{spict2DLMtool}
\title{Get function to estimate TAC for the DLMtool package}
\usage{
spict2DLMtool(percentileC = 0.5, percentileFmsy = NA, cap = TRUE)
}
\arguments{
\item{percentileC}{The percentile of the catch distribution to be used for setting TAC. Default
is median (0.5).}

\item{percentileFmsy}{The percentile of the distribution of Fmsy. Default is NA.}

\item{cap}{Logical; If true TAC is multiplied with 1 or the ratio of current biomass
over Blim (0.5*Bmsy) if this ratio is smaller than 1. Default is FALSE.}
}
\value{
A function which can estimate TAC recommendations based on SPiCT assessment,
  taking assessment uncertainty into account.
}
\details{
This function creates harvest control rules (HCRs) which can be incorporated into a
management strategy evaluation framework (DLMtool package). HCRs are saved with a
generic name to the global environment and name of HCR is returned if results of the
functin are assigned to an object. HCR runs a SPiCT assessment using catch and
relative biomass index observations and stock status estimates are used to set the TAC
for the next year. TAC can be based on the distribution of predicted catches (percentileC)
and/or the distribution of the Fmsy reference level (percentileFmsy).
Additionally, a cap can be applied to account for low biomass levels (below Bmsy).
Arguments of returned function are 'x' - the position in a data-limited mehods data object,
'Data' - the data-limited methods data object (see DLMtool), and 'reps' - the number of
stochastic samples of the TAC recommendation (not used for this HCR).
One or several arguments of the function can be provided as vectors to generate several
HCRs at once (several vectors have to have same length).
}
\examples{
\dontrun{
library(DLMtool)

## Put together an operating model from the available DLM toolkit examples
StockEx <- Herring
FleetEx <- Generic_IncE
ObsEx <- Precise_Unbiased

## Remove changes in life history parameters
StockEx@Mgrad <- c(0,0)
StockEx@Kgrad <- c(0,0)
StockEx@Linfgrad <- c(0,0)
StockEx@Prob_staying <- c(1,1)

## Set the depletion level 
StockEx@D <- c(0.3, 0.4)

## create Operation Model
OMex <- new("OM", Stock = StockEx, Fleet = FleetEx, 
                  Obs = ObsEx)

## Set simulation options
OMex@nsim <- 10
OMex@nyears <- 25
OMex@proyears <- 3

## Get SPiCT HCR
MPname <- spict2DLMtool(percentileC=0.3)

## run MSE
MSEex <- runMSE(OMex, MPs = MPname,
            interval = 1, reps = 1, timelimit = 150, CheckMPs = FALSE)
}


}
